@@ -29,6 +29,7 @@ class KerberosCredential:
 		self.kerberos_key_rc4 = None
 		self.kerberos_key_des3 = None
 		self.ccache = None
+		self.ccache_spn_strict_check = True
 
 	def get_preferred_enctype(self, server_enctypes):
 		client_enctypes = self.get_supported_enctypes(as_int=False)
@@ -123,6 +124,19 @@ class KerberosCredential:
 		if as_int == True:
 			return [etype.value for etype in supp_enctypes]
 		return [etype for etype in supp_enctypes]
+	
+	@staticmethod
+	def from_krbcred(keytab_file_path: str, principal: str = None, realm: str = None):
+		return KerberosCredential.from_kirbi(keytab_file_path, principal, realm)
+
+	@staticmethod
+	def from_kirbi(keytab_file_path: str, principal: str = None, realm: str = None):
+		cred = KerberosCredential()
+		cred.username = principal
+		cred.domain = realm
+		cred.ccache = CCACHE.from_kirbifile(keytab_file_path)
+		cred.ccache_spn_strict_check = False
+		return cred
 
 	@staticmethod
 	def from_keytab(keytab_file_path: str, principal: str, realm: str):
@@ -159,8 +173,10 @@ class KerberosCredential:
 		return cred
 
 	@staticmethod
-	def from_ccache_file(filepath):
+	def from_ccache_file(filepath, principal: str = None, realm: str = None):
 		k = KerberosCredential()
+		k.username = principal
+		k.domain = realm
 		k.ccache = CCACHE.from_file(filepath)
 		return k
 
